@@ -1,9 +1,8 @@
 export { LineAttributesEditor as default };
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
-import FormNumberInput from '../../../style/form-number-input';
-import FormTextInput from '../../../style/form-text-input';
-import PropertyLengthMeasure from '../../../../catalog/properties/property-lenght-measure';
+import { FormNumberInput, FormTextInput } from '../../../style/export';
+import { PropertyLengthMeasure } from '../../../../catalog/properties/export';
 
 var tableStyle = {
   width: '100%'
