@@ -1,18 +1,12 @@
 import Catalog from './catalog/catalog';
 import Translator from './translator/translator';
-import ToolbarComponents from './components/toolbar/export';
-import Ruler from './components/viewer2d/ruler';
 import * as Models from './models';
-import StyleComponents from './components/style/export';
-import State2DViewer from './components/viewer2d/state';
-import FooterBarComponents from './components/footerbar/export';
 import reducer from './reducers/reducer';
 import ReactPlanner from './react-planner';
-import Content from './components/content';
 import Plugins from './plugins/export';
 import * as ReactPlannerConstants from './constants';
 import * as ReactPlannerSharedStyle from './shared-style';
-
+import ReactPlannerComponents from './components/export';
 import ReactPlannerActions from './actions/export';
 import ReactPlannerReducers from './reducers/export';
 import ElementsFactories from './catalog/factories/export';
@@ -20,19 +14,14 @@ import ElementsFactories from './catalog/factories/export';
 export {
   Catalog,
   Translator,
-  StyleComponents,
-  ToolbarComponents,
-  FooterBarComponents,
-  Ruler,
   Models,
-  State2DViewer,
   reducer,
   ReactPlanner,
-  Content as ReactPlannerContent,
   Plugins,
   ElementsFactories,
   ReactPlannerConstants,
   ReactPlannerReducers,
   ReactPlannerActions,
+  ReactPlannerComponents,
   ReactPlannerSharedStyle
 };
