@@ -20,7 +20,11 @@ import {
   INIT_CATALOG,
   UPDATE_MOUSE_COORDS,
   UPDATE_ZOOM_SCALE,
-  TOGGLE_SNAP, CHANGE_CATALOG_PAGE, GO_BACK_TO_CATALOG_PAGE
+  TOGGLE_SNAP,
+  CHANGE_CATALOG_PAGE,
+  GO_BACK_TO_CATALOG_PAGE,
+  THROW_ERROR,
+  THROW_WARNING
 } from '../constants';
 
 import {State, Scene, Guide, Catalog} from "../models";
@@ -109,6 +113,12 @@ export default function (state, action) {
     case TOGGLE_SNAP:
       return toggleSnap(state, action.mask);
 
+    case THROW_ERROR:
+      return throwError(state, action.error);
+
+    case THROW_WARNING:
+      return throwWarning(state, action.warning);
+
     default:
       return state;
 
@@ -272,3 +282,15 @@ function updateZoomScale(state, scale) {
 function toggleSnap(state, mask) {
   return state.set('snapMask', mask);
 }
+
+function throwError(state, error) {
+  return state.set('errors', state.get('errors').push({
+    date: Date.now(),
+    error
+  }));
+}
+
+const throwWarning = (state, warning) => state.set('warnings', state.get('warnings').push({
+  date: Date.now(),
+  warning
+}));
